//===========================================================
//=     University of Illinois at Urbana/Champaign          =
//=     Department of Computer Science                      =
//=     Dr. Dan Roth - Cognitive Computation Group          =
//=                                                         =
//=  Project: Snow                                          =
//=                                                         =
//=   Module: Cloud.cpp                                     =
//=  Version: 2.1                                           =
//=  Authors: Jeff Rosen, Andrew Carlson                    =
//=     Date: xx/xx/99                                      = 
//=                                                         =
//= Comments:                                               =
//===========================================================

#include "Cloud.h"
#include "GlobalParams.h"
#include "Winnow.h"
#include "Perceptron.h"
#include "NaiveBayes.h"
#include <string>
#include <algorithm>
#include <math.h>

using namespace std;

double Cloud::RankTargets( Example& ex)
{
    // Before calling this function, PreparetoRank() should be called
    // to set the target activations

    double normalizedActivation = 0;
    
    TargetVector::iterator it = targets.begin();
    TargetVector::iterator end = targets.end();

	for (it = targets.begin(); it != end; it++)
    {
        normalizedActivation += 
            it->PAlgorithm()->ReturnNormalizedActivation(*it);
    }    
    return normalizedActivation;
}

void Cloud::PreparetoRank( Example& ex)
{
    // Walk through targets and set the internal activation
    TargetVector::iterator it = targets.begin();
    TargetVector::iterator end = targets.end();
    for ( ; it != end; it++)
    {
        it->PAlgorithm()->SetTargetActivation(*it, ex);
    }
}

void Cloud::Write( ofstream& out )
{
    TargetVector::iterator it = targets.begin();
    TargetVector::iterator end = targets.end();
    for ( ; it != end; it++)
    {
          it->Write(out);
    }
}


